(how-to-visualization)=

# Visualization

Guides for visualizing morphometric data and results.

```{eval-rst}
.. toctree::
    :maxdepth: 1

    morphospace
    shape_variation
    non_pca_reducer
    tps_grid
```
